from a10sdk.common.A10BaseClass import A10BaseClass


class UserList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param user: {"minLength": 1, "maxLength": 32, "type": "string", "description": "Users in the group", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "user-list"
        self.DeviceProxy = ""
        self.user = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Group(A10BaseClass):
    
    """Class Description::
    RBA configuration for a group.

    Class group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param partition_list: {"minItems": 1, "items": {"type": "partition"}, "uniqueItems": true, "array": [{"required": ["partition-name"], "properties": {"partition-name": {"description": "partition name", "format": "string", "minLength": 1, "optional": false, "maxLength": 14, "type": "string"}, "role-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "role": {"description": "Role in a given partition", "format": "string", "minLength": 1, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/rba/role"}}}]}, "rule-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"operation": {"enum": ["no-access", "read", "write"], "type": "string", "description": "'no-access': no-access; 'read': read; 'write': write; ", "format": "enum"}, "object": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Lineage of object class for permitted operation", "format": "string"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/rba/group/{name}/partition/{partition-name}"}
    :param user_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "user": {"minLength": 1, "maxLength": 32, "type": "string", "description": "Users in the group", "format": "string"}}}]}
    :param name: {"description": "Name of a RBA group", "format": "string", "minLength": 1, "optional": false, "maxLength": 32, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/rba/group/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "group"
        self.a10_url="/axapi/v3/rba/group/{name}"
        self.DeviceProxy = ""
        self.partition_list = []
        self.user_list = []
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class EthernetCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param flap_ethernet_end: {"type": "number", "description": "Ethernet Port", "format": "interface"}
    :param flap_ethernet_start: {"type": "number", "description": "Ethernet Port", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ethernet-cfg"
        self.DeviceProxy = ""
        self.flap_ethernet_end = ""
        self.flap_ethernet_start = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RestartPortList(A10BaseClass):
    
    """Class Description::
    Ports to be restarted on standby system after transition.

    Class restart-port-list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ethernet_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "flap-ethernet-end": {"type": "number", "description": "Ethernet Port", "format": "interface"}, "flap-ethernet-start": {"type": "number", "description": "Ethernet Port", "format": "interface"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/restart-port-list`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "restart-port-list"
        self.a10_url="/axapi/v3/vrrp-a/restart-port-list"
        self.DeviceProxy = ""
        self.ethernet_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class EntryList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param port_start: {"type": "number", "format": "number"}
    :param fwd_match_count: {"type": "number", "format": "number"}
    :param port_end: {"type": "number", "format": "number"}
    :param tunnel_address: {"type": "string", "format": "ipv6-address"}
    :param nat_address: {"type": "string", "format": "ipv4-address"}
    :param rev_match_count: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "entry-list"
        self.DeviceProxy = ""
        self.port_start = ""
        self.fwd_match_count = ""
        self.port_end = ""
        self.tunnel_address = ""
        self.nat_address = ""
        self.rev_match_count = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param entry_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"port-start": {"type": "number", "format": "number"}, "fwd-match-count": {"type": "number", "format": "number"}, "port-end": {"type": "number", "format": "number"}, "tunnel-address": {"type": "string", "format": "ipv6-address"}, "nat-address": {"type": "string", "format": "ipv4-address"}, "rev-match-count": {"type": "number", "format": "number"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.entry_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ActiveBindingTable(A10BaseClass):
    
    """Class Description::
    Operational Status for the object active-binding-table.

    Class active-binding-table supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lw-4o6/active-binding-table/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "active-binding-table"
        self.a10_url="/axapi/v3/cgnv6/lw-4o6/active-binding-table/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param unsol_ance_sent_fail: {"description": "Unsolicited Announce Send Failure", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param malform_request: {"description": "PCP Request Malformed", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param unsupp_option: {"description": "Unsupported PCP Option", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param unsupported_version: {"description": "Unsupported PCP version", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param no_resources: {"description": "No System or NAT Resources", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param unsupp_opcode: {"description": "Unsupported PCP Opcode", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param dslite_announce_process_success: {"description": "PCP ANNOUNCE Request Processing Success (DS-Lite)", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param l4_process_error: {"description": "L3/L4 Process Error", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param not_authorized: {"description": "PCP Request Not Authorized", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param ha_sync_epoch_sent: {"description": "HA Sync PCP Epoch Sent", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param nat64_announce_process_success: {"description": "PCP ANNOUNCE Request Processing Success (NAT64)", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param pkt_not_from_nat_inside: {"description": "Packet Dropped For Not Coming From NAT Inside", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param user_quota_exceeded: {"description": "User Quota Exceeded", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param dslite_map_process_success: {"description": "PCP MAP Request Processing Success (DS-Lite)", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param packets_rcv: {"description": "Packets Received", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param lsn_announce_process_success: {"description": "PCP ANNOUNCE Request Processing Success (NAT44)", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param cannot_provide_suggest: {"description": "Cannot Provide Suggested Port When PREFER_FAILURE", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param nat64_map_process_success: {"description": "PCP MAP Request Processing Success (NAT64)", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param internal_error_drop: {"description": "Internal Error", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param dslite_peer_process_success: {"description": "PCP PEER Request Processing Success (DS-Lite)", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param malform_option: {"description": "PCP Option Malformed", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param excessive_remote_peers: {"description": "Excessive Remote Peers", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param lsn_map_process_success: {"description": "PCP MAP Request Processing Success (NAT44)", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param unsupp_protocol: {"description": "Unsupported Mapping Protocol", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param ha_sync_epoch_rcv: {"description": "HA Sync PCP Epoch Recv", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "8"}
    :param unsol_ance_sent_succ: {"description": "Unsolicited Announce Sent", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param pkt_not_request_drop: {"description": "Packet Not a PCP Request", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param address_mismatch: {"description": "PCP Client Address Mismatch", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param noroute_drop: {"description": "Response No Route", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param lsn_peer_process_success: {"description": "PCP PEER Request Processing Success (NAT44)", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param nat64_peer_process_success: {"description": "PCP PEER Request Processing Success (NAT64)", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param pkt_too_short_drop: {"description": "Packet Too Short", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.unsol_ance_sent_fail = ""
        self.malform_request = ""
        self.unsupp_option = ""
        self.unsupported_version = ""
        self.no_resources = ""
        self.unsupp_opcode = ""
        self.dslite_announce_process_success = ""
        self.l4_process_error = ""
        self.not_authorized = ""
        self.ha_sync_epoch_sent = ""
        self.nat64_announce_process_success = ""
        self.pkt_not_from_nat_inside = ""
        self.user_quota_exceeded = ""
        self.dslite_map_process_success = ""
        self.packets_rcv = ""
        self.lsn_announce_process_success = ""
        self.cannot_provide_suggest = ""
        self.nat64_map_process_success = ""
        self.internal_error_drop = ""
        self.dslite_peer_process_success = ""
        self.malform_option = ""
        self.excessive_remote_peers = ""
        self.lsn_map_process_success = ""
        self.unsupp_protocol = ""
        self.ha_sync_epoch_rcv = ""
        self.unsol_ance_sent_succ = ""
        self.pkt_not_request_drop = ""
        self.address_mismatch = ""
        self.noroute_drop = ""
        self.lsn_peer_process_success = ""
        self.nat64_peer_process_success = ""
        self.pkt_too_short_drop = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Pcp(A10BaseClass):
    
    """Class Description::
    Statistics for the object pcp.

    Class pcp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/pcp/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "pcp"
        self.a10_url="/axapi/v3/cgnv6/pcp/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class GeoLocList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param conn_limit: {"type": "number", "format": "number"}
    :param L: {"default": 0, "type": "number", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "geo-loc-list"
        self.DeviceProxy = ""
        self.conn_limit = ""
        self.L = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ClassListGeoLocation(A10BaseClass):
    
    """Class Description::
    Configure classification list.

    Class class-list-geo-location supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param geo_loc_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"conn-limit": {"type": "number", "format": "number"}, "optional": true, "L": {"default": 0, "type": "number", "format": "flag"}}}]}
    :param name: {"description": "Specify name of the class list", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param file: {"description": "Create/Edit a class-list stored as a file", "format": "flag", "default": 0, "type": "number", "modify-not-allowed": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/class-list-geo-location/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "class-list-geo-location"
        self.a10_url="/axapi/v3/class-list-geo-location/{name}"
        self.DeviceProxy = ""
        self.geo_loc_list = []
        self.name = ""
        self.A10WW_file = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Host(A10BaseClass):
    
    """Class Description::
    Specify the hostname of TACACS+ server.

    Class host supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param tacacs_hostname_list: {"minItems": 1, "items": {"type": "tacacs-hostname"}, "uniqueItems": true, "array": [{"required": ["hostname"], "properties": {"secret": {"type": "object", "properties": {"port-cfg": {"type": "object", "properties": {"username": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify the username", "format": "string"}, "monitor": {"default": 0, "type": "number", "description": "Specify monitor TACACS+ server", "format": "flag"}, "encrypted": {"minLength": 1, "maxLength": 255, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}, "timeout": {"description": "Specify the maximum time allowed for setting up a connection with the TACACS+ server. (default timeout is 12 seconds) (Maximum time allowed for setting up a connection with the TACACS+ server, in seconds (default 12))", "format": "number", "default": 12, "maximum": 12, "minimum": 1, "type": "number"}, "password-value": {"minLength": 1, "maxLength": 31, "type": "string", "description": "The user password", "format": "password"}, "password": {"default": 0, "type": "number", "description": "Specify the user password", "format": "flag"}, "port": {"description": "Specify the port number used by TACACS+ server.( default port is 49) (Port number (default 49))", "format": "number", "default": 49, "maximum": 65535, "minimum": 1, "type": "number"}}}, "encrypted": {"minLength": 1, "maxLength": 255, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) help-val The ENCRYPTED secret string", "format": "encrypted"}, "secret-value": {"minLength": 1, "maxLength": 127, "type": "string", "description": "The TACACS+ server's secret", "format": "password"}}}, "hostname": {"description": "Hostname of TACACS+ server", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/tacacs-server/host/tacacs-hostname/{hostname}"}
    :param ipv4_list: {"minItems": 1, "items": {"type": "ipv4"}, "uniqueItems": true, "array": [{"required": ["ipv4-addr"], "properties": {"ipv4-addr": {"optional": false, "type": "string", "description": "IPV4 address of TACACS+ server", "format": "ipv4-address"}, "secret": {"type": "object", "properties": {"port-cfg": {"type": "object", "properties": {"username": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify the username", "format": "string"}, "monitor": {"default": 0, "type": "number", "description": "Specify monitor TACACS+ server", "format": "flag"}, "encrypted": {"minLength": 1, "maxLength": 255, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}, "timeout": {"description": "Specify the maximum time allowed for setting up a connection with the TACACS+ server. (default timeout is 12 seconds) (Maximum time allowed for setting up a connection with the TACACS+ server, in seconds (default 12))", "format": "number", "default": 12, "maximum": 12, "minimum": 1, "type": "number"}, "password-value": {"minLength": 1, "maxLength": 31, "type": "string", "description": "The user password", "format": "password"}, "password": {"default": 0, "type": "number", "description": "Specify the user password", "format": "flag"}, "port": {"description": "Specify the port number used by TACACS+ server.( default port is 49) (Port number (default 49))", "format": "number", "default": 49, "maximum": 65535, "minimum": 1, "type": "number"}}}, "encrypted": {"minLength": 1, "maxLength": 255, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) help-val The ENCRYPTED secret string", "format": "encrypted"}, "secret-value": {"minLength": 1, "maxLength": 127, "type": "string", "description": "The TACACS+ server's secret", "format": "password"}}}}}], "type": "array", "$ref": "/axapi/v3/tacacs-server/host/ipv4/{ipv4-addr}"}
    :param ipv6_list: {"minItems": 1, "items": {"type": "ipv6"}, "uniqueItems": true, "array": [{"required": ["ipv6-addr"], "properties": {"secret": {"type": "object", "properties": {"port-cfg": {"type": "object", "properties": {"username": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify the username", "format": "string"}, "monitor": {"default": 0, "type": "number", "description": "Specify monitor TACACS+ server", "format": "flag"}, "encrypted": {"minLength": 1, "maxLength": 255, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}, "timeout": {"description": "Specify the maximum time allowed for setting up a connection with the TACACS+ server. (default timeout is 12 seconds) (Maximum time allowed for setting up a connection with the TACACS+ server, in seconds (default 12))", "format": "number", "default": 12, "maximum": 12, "minimum": 1, "type": "number"}, "password-value": {"minLength": 1, "maxLength": 31, "type": "string", "description": "The user password", "format": "password"}, "password": {"default": 0, "type": "number", "description": "Specify the user password", "format": "flag"}, "port": {"description": "Specify the port number used by TACACS+ server.( default port is 49) (Port number (default 49))", "format": "number", "default": 49, "maximum": 65535, "minimum": 1, "type": "number"}}}, "encrypted": {"minLength": 1, "maxLength": 255, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) help-val The ENCRYPTED secret string", "format": "encrypted"}, "secret-value": {"minLength": 1, "maxLength": 127, "type": "string", "description": "The TACACS+ server's secret", "format": "password"}}}, "ipv6-addr": {"optional": false, "type": "string", "description": "IPV6 address of TACACS+ server", "format": "ipv6-address"}}}], "type": "array", "$ref": "/axapi/v3/tacacs-server/host/ipv6/{ipv6-addr}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/tacacs-server/host`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "host"
        self.a10_url="/axapi/v3/tacacs-server/host"
        self.DeviceProxy = ""
        self.tacacs_hostname_list = []
        self.ipv4_list = []
        self.ipv6_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Host(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param hostipv6: {"not": "hostip", "type": "string", "description": "Server's IPV6 address", "format": "ipv6-address"}
    :param hostip: {"description": "Server's hostname(Length 1-31) or IP address", "format": "host", "minLength": 1, "maxLength": 31, "not": "hostipv6", "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "host"
        self.DeviceProxy = ""
        self.hostipv6 = ""
        self.hostip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DeriveBindDn(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param username_attr: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify attribute name of username", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "derive-bind-dn"
        self.DeviceProxy = ""
        self.username_attr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Instance(A10BaseClass):
    
    """Class Description::
    LDAP Authentication Server.

    Class instance supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param health_check_string: {"description": "Health monitor name", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/health/monitor"}
    :param port_hm: {"description": "Check port's health status", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "port-hm-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}
    :param name: {"description": "Specify LDAP authentication server name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param port_hm_disable: {"description": "Disable configured port health check configuration", "format": "flag", "default": 0, "optional": true, "not": "port-hm", "type": "number"}
    :param admin_dn: {"description": "The LDAP server's admin DN", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}
    :param default_domain: {"description": "Specify default domain for LDAP, cannot include \"\\\"", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param health_check_disable: {"description": "Disable configured health check configuration", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}
    :param admin_secret: {"default": 0, "optional": true, "type": "number", "description": "Specify the LDAP server's admin secret password", "format": "flag"}
    :param health_check: {"description": "Check server's health status", "format": "flag", "default": 0, "optional": true, "not": "health-check-disable", "type": "number"}
    :param bind_with_dn: {"default": 0, "optional": true, "type": "number", "description": "Enforce using DN for LDAP binding", "format": "flag"}
    :param base: {"description": "Specify the LDAP server's search base", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param dn_attribute: {"description": "Specify Distinguished Name attribute, default is CN", "format": "string-rlx", "default": "cn", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param timeout: {"description": "Specify timout for LDAP, default is 10 seconds (The timeout, default is 10 seconds)", "format": "number", "default": 10, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}
    :param pwdmaxage: {"description": "Specify the LDAP server's default password expiration time (in seconds) (The LDAP server's default password expiration time (in seconds), default is 0 (no expiration))", "format": "number", "default": 0, "optional": true, "maximum": 4294967295, "minimum": 0, "type": "number"}
    :param port: {"description": "Specify the LDAP server's authentication port, default is 389", "format": "number", "default": 389, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param secret_string: {"description": "secret password", "format": "password", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/server/ldap/instance/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "instance"
        self.a10_url="/axapi/v3/aam/authentication/server/ldap/instance/{name}"
        self.DeviceProxy = ""
        self.health_check_string = ""
        self.port_hm = ""
        self.name = ""
        self.port_hm_disable = ""
        self.admin_dn = ""
        self.encrypted = ""
        self.default_domain = ""
        self.health_check_disable = ""
        self.admin_secret = ""
        self.health_check = ""
        self.bind_with_dn = ""
        self.host = {}
        self.base = ""
        self.dn_attribute = ""
        self.timeout = ""
        self.pwdmaxage = ""
        self.derive_bind_dn = {}
        self.port = ""
        self.secret_string = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param nm_response: {"optional": true, "size": "2", "type": "number", "oid": "11", "format": "counter"}
    :param rsp_type_304: {"optional": true, "size": "2", "type": "number", "oid": "14", "format": "counter"}
    :param rsp_other: {"optional": true, "size": "2", "type": "number", "oid": "19", "format": "counter"}
    :param content_toosmall: {"optional": true, "size": "2", "type": "number", "oid": "24", "format": "counter"}
    :param entry_create_failures: {"optional": true, "size": "2", "type": "number", "oid": "25", "format": "counter"}
    :param nocache_match: {"optional": true, "size": "2", "type": "number", "oid": "20", "format": "counter"}
    :param content_toobig: {"optional": true, "size": "2", "type": "number", "oid": "23", "format": "counter"}
    :param nc_res_header: {"optional": true, "size": "2", "type": "number", "oid": "7", "format": "counter"}
    :param miss: {"optional": true, "size": "2", "type": "number", "oid": "2", "format": "counter"}
    :param nc_req_header: {"optional": true, "size": "2", "type": "number", "oid": "6", "format": "counter"}
    :param replaced_entry: {"optional": true, "size": "8", "type": "number", "oid": "28", "format": "counter"}
    :param aging_entry: {"optional": true, "size": "8", "type": "number", "oid": "29", "format": "counter"}
    :param mem_size: {"optional": true, "size": "8", "type": "number", "oid": "26", "format": "counter"}
    :param rsp_deflate: {"optional": true, "size": "2", "type": "number", "oid": "18", "format": "counter"}
    :param invalidate_match: {"optional": true, "size": "2", "type": "number", "oid": "22", "format": "counter"}
    :param match: {"optional": true, "size": "2", "type": "number", "oid": "21", "format": "counter"}
    :param cleaned_entry: {"optional": true, "size": "8", "type": "number", "oid": "30", "format": "counter"}
    :param entry_num: {"optional": true, "size": "8", "type": "number", "oid": "27", "format": "counter"}
    :param total_req: {"optional": true, "size": "2", "type": "number", "oid": "4", "format": "counter"}
    :param bytes_served: {"optional": true, "size": "2", "type": "number", "oid": "3", "format": "counter"}
    :param rv_success: {"optional": true, "size": "2", "type": "number", "oid": "8", "format": "counter"}
    :param rv_failure: {"optional": true, "size": "2", "type": "number", "oid": "9", "format": "counter"}
    :param rsp_gzip: {"optional": true, "size": "2", "type": "number", "oid": "17", "format": "counter"}
    :param hits: {"optional": true, "size": "2", "type": "number", "oid": "1", "format": "counter"}
    :param rsp_type_other: {"optional": true, "size": "2", "type": "number", "oid": "15", "format": "counter"}
    :param rsp_type_CE: {"optional": true, "size": "2", "type": "number", "oid": "13", "format": "counter"}
    :param rsp_no_compress: {"optional": true, "size": "2", "type": "number", "oid": "16", "format": "counter"}
    :param rsp_type_CL: {"optional": true, "size": "2", "type": "number", "oid": "12", "format": "counter"}
    :param caching_req: {"optional": true, "size": "2", "type": "number", "oid": "5", "format": "counter"}
    :param ims_request: {"optional": true, "size": "2", "type": "number", "oid": "10", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.nm_response = ""
        self.rsp_type_304 = ""
        self.rsp_other = ""
        self.content_toosmall = ""
        self.entry_create_failures = ""
        self.nocache_match = ""
        self.content_toobig = ""
        self.nc_res_header = ""
        self.miss = ""
        self.nc_req_header = ""
        self.replaced_entry = ""
        self.aging_entry = ""
        self.mem_size = ""
        self.rsp_deflate = ""
        self.invalidate_match = ""
        self.match = ""
        self.cleaned_entry = ""
        self.entry_num = ""
        self.total_req = ""
        self.bytes_served = ""
        self.rv_success = ""
        self.rv_failure = ""
        self.rsp_gzip = ""
        self.hits = ""
        self.rsp_type_other = ""
        self.rsp_type_CE = ""
        self.rsp_no_compress = ""
        self.rsp_type_CL = ""
        self.caching_req = ""
        self.ims_request = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Cache(A10BaseClass):
    
    """Class Description::
    Statistics for the object cache.

    Class cache supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Specify cache template name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/cache/{name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "cache"
        self.a10_url="/axapi/v3/slb/template/cache/{name}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Template(A10BaseClass):
    
    """Class Description::
    HSM Template.

    Class template supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param password_string: {"description": "Password (minimum 4 characters)", "format": "password", "minLength": 4, "optional": true, "maxLength": 31, "type": "string"}
    :param encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually (This is an A10 reserved keyword) (The ENCRYPTED password string)", "format": "encrypted"}
    :param softhsm_enum: {"optional": true, "enum": ["softHSM"], "type": "string", "description": "'softHSM': software implementation of a cryptographic store; ", "format": "enum"}
    :param password: {"default": 0, "optional": true, "type": "number", "description": "Specify HSM Passphrase", "format": "flag"}
    :param template_name: {"description": "Specify Template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/hsm/template/{template_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "template_name"]

        self.b_key = "template"
        self.a10_url="/axapi/v3/hsm/template/{template_name}"
        self.DeviceProxy = ""
        self.password_string = ""
        self.encrypted = ""
        self.softhsm_enum = ""
        self.password = ""
        self.template_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Poap(A10BaseClass):
    
    """    :param action: {"optional": true, "enum": ["enable", "disable"], "type": "string", "description": "'enable': Enable POAP mode; 'disable': Disable POAP mode; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Set POAP; when next boot, if startup-config is empty, system will enter POAP Mode.

    Class poap supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/poap`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "poap"
        self.a10_url="/axapi/v3/poap"
        self.DeviceProxy = ""
        self.action = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Encoding_fail: {"description": "Encoding Failure", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param Http_code_other: {"description": "Other HTTP Response", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param Success: {"description": "Success", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param Http_code_200: {"description": "HTTP 200 OK", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param Http_code_401: {"description": "HTTP 401 Unauthorized", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param Internal_error: {"description": "Internal Error", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param Parse_header_fail: {"description": "Parse Header Failure", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param Request: {"description": "Request", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param Http_code_400: {"description": "HTTP 400 Bad Request", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param Failure: {"description": "Failure", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param Buffer_alloc_fail: {"description": "Buffer Allocation Failure", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param Http_code_403: {"description": "HTTP 403 Forbidden", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param Http_code_404: {"description": "HTTP 404 Not Found", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param Http_code_500: {"description": "HTTP 500 Internal Server Error", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param Http_code_503: {"description": "HTTP 503 Service Unavailable", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param Response: {"description": "Response", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param Insert_header_fail: {"description": "Insert Header Failure", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.Encoding_fail = ""
        self.Http_code_other = ""
        self.Success = ""
        self.Http_code_200 = ""
        self.Http_code_401 = ""
        self.Internal_error = ""
        self.Parse_header_fail = ""
        self.Request = ""
        self.Http_code_400 = ""
        self.Failure = ""
        self.Buffer_alloc_fail = ""
        self.Http_code_403 = ""
        self.Http_code_404 = ""
        self.Http_code_500 = ""
        self.Http_code_503 = ""
        self.Response = ""
        self.Insert_header_fail = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ntlm(A10BaseClass):
    
    """Class Description::
    Statistics for the object ntlm.

    Class ntlm supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Specify NTLM authentication relay name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/relay/ntlm/{name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "ntlm"
        self.a10_url="/axapi/v3/aam/authentication/relay/ntlm/{name}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PortCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ssl: {"default": 0, "type": "number", "description": "Use SSL", "format": "flag"}
    :param port: {"description": "Specify the LDAP server's port (default 389 without ssl or 636 with ssl)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param timeout: {"description": "Specify the LDAP server's timeout (default 3)", "minimum": 1, "type": "number", "maximum": 60, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "port-cfg"
        self.DeviceProxy = ""
        self.ssl = ""
        self.port = ""
        self.timeout = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LdapHostname(A10BaseClass):
    
    """Class Description::
    Specify the hostname of LDAP server.

    Class ldap-hostname supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param cn_value: {"description": "LDAP common name identifier (i.e.: cn, uid)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param hostname: {"description": "Hostname of LDAP server", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param dn_value: {"description": "LDAP distinguished name (dn)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ldap-server/host/ldap-hostname/{hostname}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "hostname"]

        self.b_key = "ldap-hostname"
        self.a10_url="/axapi/v3/ldap-server/host/ldap-hostname/{hostname}"
        self.DeviceProxy = ""
        self.port_cfg = {}
        self.cn_value = ""
        self.hostname = ""
        self.dn_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ddos(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param outside: {"default": 0, "type": "number", "description": "DDoS outside (untrusted) interface", "format": "flag"}
    :param inside: {"default": 0, "type": "number", "description": "DDoS inside (trusted) interface", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ddos"
        self.DeviceProxy = ""
        self.outside = ""
        self.inside = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AccessList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl_name: {"minLength": 1, "maxLength": 16, "type": "string", "description": "Apply an access list (Named Access List)", "format": "string"}
    :param acl_id: {"description": "ACL id", "format": "number", "maximum": 199, "minimum": 1, "type": "number", "$ref": "/axapi/v3/access-list/standard"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "access-list"
        self.DeviceProxy = ""
        self.acl_name = ""
        self.acl_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Icmpv6RateLimit(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param lockup_period_v6: {"description": "Lockup period (second)", "minimum": 1, "type": "number", "maximum": 16383, "format": "number"}
    :param normal_v6: {"description": "Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param lockup_v6: {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "icmpv6-rate-limit"
        self.DeviceProxy = ""
        self.lockup_period_v6 = ""
        self.normal_v6 = ""
        self.lockup_v6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class MonitorList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param monitor_vlan: {"description": "VLAN number", "format": "number", "maximum": 4094, "minimum": 2, "type": "number", "plat-neg-list": ["non-fpga"]}
    :param monitor: {"description": "'input': Incoming packets; 'output': Outgoing packets; 'both': Both incoming and outgoing packets; ", "partition-visibility": "shared", "format": "enum", "enum": ["input", "output", "both"], "type": "string", "plat-neg-list": ["soft-ax"]}
    :param mirror_index: {"description": "Mirror index", "format": "number", "maximum": 4, "minimum": 1, "type": "number", "plat-neg-list": ["soft-ax"], "$ref": "/axapi/v3/mirror-port"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "monitor-list"
        self.DeviceProxy = ""
        self.monitor_vlan = ""
        self.monitor = ""
        self.mirror_index = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IcmpRateLimit(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param lockup: {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param lockup_period: {"description": "Lockup period (second)", "minimum": 1, "type": "number", "maximum": 16383, "format": "number"}
    :param normal: {"description": "Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "icmp-rate-limit"
        self.DeviceProxy = ""
        self.lockup = ""
        self.lockup_period = ""
        self.normal = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ethernet(A10BaseClass):
    
    """Class Description::
    Ethernet interface.

    Class ethernet supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param trap_source: {"default": 0, "optional": true, "type": "number", "description": "The trap source", "format": "flag"}
    :param speed: {"description": "'10': 10; '100': 100; '1000': 1000; 'auto': auto; ", "format": "enum", "default": "auto", "optional": true, "enum": ["10", "100", "1000", "auto"], "type": "string", "plat-neg-list": ["soft-ax"]}
    :param media_type_copper: {"description": "Set the media type to copper", "format": "flag", "default": 0, "type": "number", "optional": true, "plat-neg-list": ["non-fpga", "soft-ax"]}
    :param remove_vlan_tag: {"description": "Remove the vlan tag for egressing packets", "format": "flag", "default": 0, "type": "number", "optional": true, "plat-neg-list": ["non-fpga", "soft-ax"]}
    :param load_interval: {"description": "Configure Load Interval (Seconds (5-300, Multiple of 5), default 300)", "format": "number", "default": 300, "optional": true, "maximum": 300, "minimum": 5, "type": "number"}
    :param cpu_process: {"description": "All Packets to this port are processed by CPU", "format": "flag", "default": 0, "type": "number", "optional": true, "plat-neg-list": ["non-fpga", "soft-ax"]}
    :param trunk_group_list: {"minItems": 1, "items": {"type": "trunk-group"}, "uniqueItems": true, "array": [{"required": ["trunk-number"], "properties": {"trunk-number": {"description": "Trunk Number", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": false}, "udld-timeout-cfg": {"type": "object", "properties": {"slow": {"description": "slow timeout in unit of seconds", "format": "number", "default": 1, "maximum": 60, "minimum": 1, "not": "fast", "type": "number"}, "fast": {"description": "fast timeout in unit of milli-seconds", "format": "number", "default": 1000, "maximum": 1000, "minimum": 100, "not": "slow", "type": "number"}}}, "mode": {"description": "'active': enable initiation of LACP negotiation on a port(default); 'passive': disable initiation of LACP negotiation on a port; ", "format": "enum", "default": "active", "type": "string", "enum": ["active", "passive"], "optional": true}, "timeout": {"description": "'long': Set LACP long timeout (default); 'short': Set LACP short timeout; ", "format": "enum", "default": "long", "type": "string", "enum": ["long", "short"], "optional": true}, "type": {"description": "'static': Static (default); 'lacp': lacp; 'lacp-udld': lacp-udld; ", "format": "enum", "default": "static", "optional": true, "enum": ["static", "lacp", "lacp-udld"], "modify-not-allowed": 1, "type": "string"}, "admin-key": {"description": "LACP admin key (Admin key value)", "format": "number", "type": "number", "maximum": 65535, "minimum": 10000, "optional": true}, "port-priority": {"description": "Set LACP priority for a port (LACP port priority)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/interface/ethernet/{ifnum}/trunk-group/{trunk-number}"}
    :param l3_vlan_fwd_disable: {"default": 0, "optional": true, "type": "number", "format": "flag"}
    :param name: {"description": "Name for the interface", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 32, "type": "string"}
    :param duplexity: {"description": "'Full': Full; 'Half': Half; 'auto': auto; ", "format": "enum", "default": "auto", "optional": true, "enum": ["Full", "Half", "auto"], "type": "string", "plat-neg-list": ["soft-ax"]}
    :param mtu: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Interface mtu (Interface MTU, default 1500 (min MTU is 1280 for IPv6))", "format": "number", "optional": true, "type": "number"}
    :param ifnum: {"optional": false, "type": "number", "description": "Ethernet interface number", "format": "interface"}
    :param monitor_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "monitor-vlan": {"description": "VLAN number", "format": "number", "maximum": 4094, "minimum": 2, "type": "number", "plat-neg-list": ["non-fpga"]}, "monitor": {"description": "'input': Incoming packets; 'output': Outgoing packets; 'both': Both incoming and outgoing packets; ", "partition-visibility": "shared", "format": "enum", "enum": ["input", "output", "both"], "type": "string", "plat-neg-list": ["soft-ax"]}, "mirror-index": {"description": "Mirror index", "format": "number", "maximum": 4, "minimum": 1, "type": "number", "plat-neg-list": ["soft-ax"], "$ref": "/axapi/v3/mirror-port"}}}]}
    :param action: {"description": "'enable': Enable; 'disable': Disable; ", "format": "enum", "default": "disable", "type": "string", "enum": ["enable", "disable"], "optional": true}
    :param flow_control: {"description": "Enable 802.3x flow control on full duplex port", "format": "flag", "default": 0, "type": "number", "optional": true, "plat-neg-list": ["soft-ax"]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/ethernet/{ifnum}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ifnum"]

        self.b_key = "ethernet"
        self.a10_url="/axapi/v3/interface/ethernet/{ifnum}"
        self.DeviceProxy = ""
        self.trap_source = ""
        self.ip = {}
        self.ddos = {}
        self.access_list = {}
        self.speed = ""
        self.lldp = {}
        self.bfd = {}
        self.media_type_copper = ""
        self.remove_vlan_tag = ""
        self.load_interval = ""
        self.cpu_process = ""
        self.ipv6 = {}
        self.trunk_group_list = []
        self.l3_vlan_fwd_disable = ""
        self.isis = {}
        self.name = ""
        self.duplexity = ""
        self.icmpv6_rate_limit = {}
        self.mtu = ""
        self.ifnum = ""
        self.monitor_list = []
        self.lw_4o6 = {}
        self.action = ""
        self.icmp_rate_limit = {}
        self.flow_control = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Geofiles(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param success: {"type": "number", "format": "number"}
    :param error_warning: {"type": "number", "format": "number"}
    :param lines: {"type": "number", "format": "number"}
    :param filename: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param template: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param percentage_loaded: {"type": "number", "format": "number"}
    :param type: {"enum": ["template", "builtin"], "type": "string", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "geofiles"
        self.DeviceProxy = ""
        self.success = ""
        self.error_warning = ""
        self.lines = ""
        self.filename = ""
        self.template = ""
        self.percentage_loaded = ""
        self.A10WW_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param geofiles: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"success": {"type": "number", "format": "number"}, "error-warning": {"type": "number", "format": "number"}, "lines": {"type": "number", "format": "number"}, "filename": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "template": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "percentage-loaded": {"type": "number", "format": "number"}, "type": {"enum": ["template", "builtin"], "type": "string", "format": "enum"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.geofiles = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class GeolocationFile(A10BaseClass):
    
    """Class Description::
    Operational Status for the object geolocation-file.

    Class geolocation-file supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/geolocation-file/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "geolocation-file"
        self.a10_url="/axapi/v3/gslb/geolocation-file/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class KeyChainCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param key_chain_flag: {"default": 0, "type": "number", "description": "Key-chain management", "format": "flag"}
    :param key_chain_name: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Key-chain name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "key-chain-cfg"
        self.DeviceProxy = ""
        self.key_chain_flag = ""
        self.key_chain_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Key(A10BaseClass):
    
    """Class Description::
    Authentication key management.

    Class key supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param key_list: {"minItems": 1, "items": {"type": "key"}, "uniqueItems": true, "array": [{"required": ["key-number"], "properties": {"key-number": {"description": "Key identifier number", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": false}, "key-string": {"description": "Set key string (The key)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/key/{key-chain-flag}+{key-chain-name}/key/{key-number}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/key/{key_chain_flag}+{key_chain_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "key_chain_flag","key_chain_name"]

        self.b_key = "key"
        self.a10_url="/axapi/v3/key/{key_chain_flag}+{key_chain_name}"
        self.DeviceProxy = ""
        self.key_chain_cfg = {}
        self.key_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Imap(A10BaseClass):
    
    """Class Description::
    IMAP type.

    Class imap supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param imap_cram_md5: {"default": 0, "optional": true, "type": "number", "description": "Challenge-response authentication mechanism", "format": "flag"}
    :param imap_port: {"description": "Specify the IMAP port, default is 143 (Port Number (default 143))", "format": "number", "default": 143, "optional": true, "maximum": 65534, "minimum": 1, "type": "number"}
    :param imap_login: {"default": 0, "optional": true, "type": "number", "description": "Simple login", "format": "flag"}
    :param imap_password: {"default": 0, "optional": true, "type": "number", "description": "Specify the user password", "format": "flag"}
    :param imap_password_string: {"description": "Configure password, '' means empty passworddd", "format": "password", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param imap_username: {"description": "Specify the username", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param imap_encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param pwd_auth: {"default": 0, "optional": true, "type": "number", "description": "Specify the Authentication method", "format": "flag"}
    :param imap_plain: {"default": 0, "optional": true, "type": "number", "description": "Plain text", "format": "flag"}
    :param imap: {"default": 0, "optional": true, "type": "number", "description": "IMAP type", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}/method/imap`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "imap"
        self.a10_url="/axapi/v3/health/monitor/{name}/method/imap"
        self.DeviceProxy = ""
        self.imap_cram_md5 = ""
        self.imap_port = ""
        self.imap_login = ""
        self.imap_password = ""
        self.imap_password_string = ""
        self.imap_username = ""
        self.imap_encrypted = ""
        self.pwd_auth = ""
        self.imap_plain = ""
        self.imap = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class MirrorPort(A10BaseClass):
    
    """Class Description::
    Enable a port to act as Mirror Port.

    Class mirror-port supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ethernet: {"optional": true, "type": "number", "description": "Ethernet port as mirror port (Port Value)", "format": "interface"}
    :param mirror_index: {"description": "Mirror index", "format": "number", "type": "number", "maximum": 4, "minimum": 1, "optional": false}
    :param mirror_dir: {"description": "'input': Mirror incoming packets to this port; 'output': Mirror outgoing packets to this port; 'both': Mirror both incoming and outgoing packets to this port; ", "format": "enum", "default": "both", "type": "string", "enum": ["input", "output", "both"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/mirror-port/{mirror_index}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "mirror_index"]

        self.b_key = "mirror-port"
        self.a10_url="/axapi/v3/mirror-port/{mirror_index}"
        self.DeviceProxy = ""
        self.ethernet = ""
        self.mirror_index = ""
        self.mirror_dir = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class VipList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param metric: {"description": "Metric for redistributed routes (metric value)", "minimum": 0, "type": "number", "maximum": 16, "format": "number"}
    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param type: {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "'only-flagged': Selected Virtual IP (VIP); 'only-not-flagged': Only not flagged; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vip-list"
        self.DeviceProxy = ""
        self.metric = ""
        self.route_map = ""
        self.A10WW_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RedistList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param metric: {"description": "Metric for redistributed routes (metric value)", "minimum": 0, "type": "number", "maximum": 16, "format": "number"}
    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param type: {"enum": ["bgp", "connected", "floating-ip", "ip-nat-list", "ip-nat", "isis", "lw4o6", "ospf", "static"], "type": "string", "description": "'bgp': Border Gateway Protocol (BGP); 'connected': Connected; 'floating-ip': Floating IP; 'ip-nat-list': IP NAT list; 'ip-nat': IP NAT; 'isis': ISO IS-IS; 'lw4o6': LW4O6 Prefix; 'ospf': Open Shortest Path First (OSPF); 'static': Static routes; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "redist-list"
        self.DeviceProxy = ""
        self.metric = ""
        self.route_map = ""
        self.A10WW_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Redistribute(A10BaseClass):
    
    """Class Description::
    Redistribute information from another routing protocol.

    Class redistribute supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vip_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "metric": {"description": "Metric for redistributed routes (metric value)", "minimum": 0, "type": "number", "maximum": 16, "format": "number"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "type": {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "'only-flagged': Selected Virtual IP (VIP); 'only-not-flagged': Only not flagged; ", "format": "enum"}}}]}
    :param redist_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "metric": {"description": "Metric for redistributed routes (metric value)", "minimum": 0, "type": "number", "maximum": 16, "format": "number"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "type": {"enum": ["bgp", "connected", "floating-ip", "ip-nat-list", "ip-nat", "isis", "lw4o6", "ospf", "static"], "type": "string", "description": "'bgp': Border Gateway Protocol (BGP); 'connected': Connected; 'floating-ip': Floating IP; 'ip-nat-list': IP NAT list; 'ip-nat': IP NAT; 'isis': ISO IS-IS; 'lw4o6': LW4O6 Prefix; 'ospf': Open Shortest Path First (OSPF); 'static': Static routes; ", "format": "enum"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/rip/redistribute`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "redistribute"
        self.a10_url="/axapi/v3/router/rip/redistribute"
        self.DeviceProxy = ""
        self.vip_list = []
        self.redist_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class MemberList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param member: {"description": "Partition Name", "format": "string", "minLength": 1, "maxLength": 14, "type": "string", "$ref": "/axapi/v3/partition"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "member-list"
        self.DeviceProxy = ""
        self.member = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PartitionGroup(A10BaseClass):
    
    """Class Description::
    Modify a partition group.

    Class partition-group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param partition_group_name: {"description": "Partition Group Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param member_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"member": {"description": "Partition Name", "format": "string", "minLength": 1, "maxLength": 14, "type": "string", "$ref": "/axapi/v3/partition"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/partition-group/{partition_group_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "partition_group_name"]

        self.b_key = "partition-group"
        self.a10_url="/axapi/v3/partition-group/{partition_group_name}"
        self.DeviceProxy = ""
        self.partition_group_name = ""
        self.member_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ntlm(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ntlm_enable: {"default": 0, "type": "number", "description": "Enable NTLM logon", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ntlm"
        self.DeviceProxy = ""
        self.ntlm_enable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Negotiate(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param negotiate_enable: {"default": 0, "type": "number", "description": "Enable SPENGO logon", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "negotiate"
        self.DeviceProxy = ""
        self.negotiate_enable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Basic(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param new_pin_page: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new PIN page name for RSA-RADIUS", "format": "string-rlx"}
    :param basic_enable: {"default": 0, "type": "number", "description": "Enable Basic logon", "format": "flag"}
    :param next_token_variable: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify next-token variable name", "format": "string-rlx"}
    :param next_token_page: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify next-token page name for RSA-RADIUS", "format": "string-rlx"}
    :param basic_realm: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify realm for basic logon", "format": "string-rlx"}
    :param new_pin_variable: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new PIN variable name", "format": "string-rlx"}
    :param challenge_response_form: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify challenge-response form for RSA-RADIUS authentication", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "basic"
        self.DeviceProxy = ""
        self.new_pin_page = ""
        self.basic_enable = ""
        self.next_token_variable = ""
        self.next_token_page = ""
        self.basic_realm = ""
        self.new_pin_variable = ""
        self.challenge_response_form = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AuthMethod(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "auth-method"
        self.DeviceProxy = ""
        self.ntlm = {}
        self.negotiate = {}
        self.basic = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Instance(A10BaseClass):
    
    """Class Description::
    HTTP-authenticate Logon.

    Class instance supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param retry: {"description": "Specify max. number of failure retry (1 ~ 32), default is 3", "format": "number", "default": 3, "optional": true, "maximum": 32, "minimum": 1, "type": "number"}
    :param name: {"description": "Specify HTTP-Authenticate logon name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/logon/http-authenticate/instance/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "instance"
        self.a10_url="/axapi/v3/aam/authentication/logon/http-authenticate/instance/{name}"
        self.DeviceProxy = ""
        self.retry = ""
        self.name = ""
        self.auth_method = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class RedistList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param type: {"enum": ["bgp", "connected", "floating-ip", "ip-nat-list", "lw4o6", "isis", "rip", "static"], "type": "string", "description": "'bgp': Border Gateway Protocol (BGP); 'connected': Connected; 'floating-ip': Floating IP; 'ip-nat-list': IP NAT list; 'lw4o6': LW4O6 Prefix; 'isis': ISO IS-IS; 'rip': Routing Information Protocol (RIP); 'static': Static routes; ", "format": "enum"}
    :param metric: {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}
    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param tag: {"description": "Set tag for routes redistributed into OSPF (32-bit tag value)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param metric_type: {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "redist-list"
        self.DeviceProxy = ""
        self.A10WW_type = ""
        self.metric = ""
        self.route_map = ""
        self.tag = ""
        self.metric_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class OspfList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param tag_ospf: {"description": "Set tag for routes redistributed into OSPF (32-bit tag value)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param process_id: {"description": "OSPF process ID", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param route_map_ospf: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param metric_ospf: {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}
    :param ospf: {"default": 0, "type": "number", "description": "Open Shortest Path First (OSPF)", "format": "flag"}
    :param metric_type_ospf: {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ospf-list"
        self.DeviceProxy = ""
        self.tag_ospf = ""
        self.process_id = ""
        self.route_map_ospf = ""
        self.metric_ospf = ""
        self.ospf = ""
        self.metric_type_ospf = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpNatFloatingList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip_nat_floating_IP_forward: {"type": "string", "description": "Floating-IP as forward address", "format": "ipv4-address"}
    :param ip_nat_prefix: {"type": "string", "description": "Address", "format": "ipv4-cidr"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-nat-floating-list"
        self.DeviceProxy = ""
        self.ip_nat_floating_IP_forward = ""
        self.ip_nat_prefix = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VipFloatingList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param vip_address: {"type": "string", "description": "Address", "format": "ipv4-address"}
    :param vip_floating_IP_forward: {"type": "string", "description": "Floating-IP as forward address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vip-floating-list"
        self.DeviceProxy = ""
        self.vip_address = ""
        self.vip_floating_IP_forward = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VipList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param metric_type_vip: {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}
    :param tag_vip: {"type": "number", "description": "Set tag for routes redistributed into OSPF (32-bit tag value)", "format": "number"}
    :param metric_vip: {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}
    :param route_map_vip: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param type_vip: {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "'only-flagged': Selected Virtual IP (VIP); 'only-not-flagged': Only not flagged; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vip-list"
        self.DeviceProxy = ""
        self.metric_type_vip = ""
        self.tag_vip = ""
        self.metric_vip = ""
        self.route_map_vip = ""
        self.type_vip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Redistribute(A10BaseClass):
    
    """Class Description::
    Redistribute information from another routing protocol.

    Class redistribute supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param redist_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"type": {"enum": ["bgp", "connected", "floating-ip", "ip-nat-list", "lw4o6", "isis", "rip", "static"], "type": "string", "description": "'bgp': Border Gateway Protocol (BGP); 'connected': Connected; 'floating-ip': Floating IP; 'ip-nat-list': IP NAT list; 'lw4o6': LW4O6 Prefix; 'isis': ISO IS-IS; 'rip': Routing Information Protocol (RIP); 'static': Static routes; ", "format": "enum"}, "metric": {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "tag": {"description": "Set tag for routes redistributed into OSPF (32-bit tag value)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "optional": true, "metric-type": {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}}}]}
    :param ospf_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "tag-ospf": {"description": "Set tag for routes redistributed into OSPF (32-bit tag value)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "process-id": {"description": "OSPF process ID", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "route-map-ospf": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "metric-ospf": {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "ospf": {"default": 0, "type": "number", "description": "Open Shortest Path First (OSPF)", "format": "flag"}, "metric-type-ospf": {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}}}]}
    :param ip_nat_floating_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip-nat-floating-IP-forward": {"type": "string", "description": "Floating-IP as forward address", "format": "ipv4-address"}, "optional": true, "ip-nat-prefix": {"type": "string", "description": "Address", "format": "ipv4-cidr"}}}]}
    :param vip: {"default": 0, "optional": true, "type": "number", "description": "Virtual IP (VIP)", "format": "flag"}
    :param tag_ip_nat: {"optional": true, "type": "number", "description": "Set tag for routes redistributed into OSPF (32-bit tag value)", "format": "number"}
    :param ip_nat: {"default": 0, "optional": true, "type": "number", "description": "IP-NAT", "format": "flag"}
    :param metric_ip_nat: {"description": "OSPF default metric (OSPF metric)", "format": "number", "type": "number", "maximum": 16777214, "minimum": 0, "optional": true}
    :param route_map_ip_nat: {"description": "Route map reference (Pointer to route-map entries)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param vip_floating_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "vip-address": {"type": "string", "description": "Address", "format": "ipv4-address"}, "vip-floating-IP-forward": {"type": "string", "description": "Floating-IP as forward address", "format": "ipv4-address"}}}]}
    :param metric_type_ip_nat: {"description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum", "default": "2", "type": "string", "enum": ["1", "2"], "optional": true}
    :param vip_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"metric-type-vip": {"default": "2", "enum": ["1", "2"], "type": "string", "description": "'1': Set OSPF External Type 1 metrics; '2': Set OSPF External Type 2 metrics; ", "format": "enum"}, "tag-vip": {"type": "number", "description": "Set tag for routes redistributed into OSPF (32-bit tag value)", "format": "number"}, "metric-vip": {"description": "OSPF default metric (OSPF metric)", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "route-map-vip": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}, "optional": true, "type-vip": {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "'only-flagged': Selected Virtual IP (VIP); 'only-not-flagged': Only not flagged; ", "format": "enum"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ospf/{process_id}/redistribute`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "redistribute"
        self.a10_url="/axapi/v3/router/ospf/{process_id}/redistribute"
        self.DeviceProxy = ""
        self.redist_list = []
        self.ospf_list = []
        self.ip_nat_floating_list = []
        self.vip = ""
        self.tag_ip_nat = ""
        self.ip_nat = ""
        self.metric_ip_nat = ""
        self.route_map_ip_nat = ""
        self.vip_floating_list = []
        self.metric_type_ip_nat = ""
        self.vip_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param total_system_memory: {"type": "number", "format": "number"}
    :param total_free_fpga_buff: {"type": "number", "format": "number"}
    :param total_fpga_buffers: {"type": "number", "format": "number"}
    :param free_fpga_buffers: {"type": "number", "format": "number"}
    :param free_session_memory: {"type": "number", "format": "number"}
    :param avail_fpga_buff_domain1: {"type": "number", "format": "number"}
    :param avail_fpga_buff_domain2: {"type": "number", "format": "number"}
    :param total_session_memory: {"type": "number", "format": "number"}
    :param fpga_buff_recovery_threshold: {"type": "number", "format": "number"}
    :param sess_mem_recovery_threshold: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.total_system_memory = ""
        self.total_free_fpga_buff = ""
        self.total_fpga_buffers = ""
        self.free_fpga_buffers = ""
        self.free_session_memory = ""
        self.avail_fpga_buff_domain1 = ""
        self.avail_fpga_buff_domain2 = ""
        self.total_session_memory = ""
        self.fpga_buff_recovery_threshold = ""
        self.sess_mem_recovery_threshold = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class FailSafe(A10BaseClass):
    
    """Class Description::
    Operational Status for the object fail-safe.

    Class fail-safe supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/fail-safe/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "fail-safe"
        self.a10_url="/axapi/v3/fail-safe/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param start_server_conn: {"description": "Start server conn", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param service_alloc_cb: {"description": "Service alloc callback", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param start_server_conn_fail_tuple: {"description": "Fail Tuple Issue", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param client_rst: {"description": "Client RST", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param queue_depth_over_limit: {"description": "Queue depth over limit", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param start_server_conn_fail_mem: {"description": "No memory", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param start_server_conn_fail_server: {"description": "Fail Server issue", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param service_free_cb_failed: {"description": "Service free callback failed", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param est_event: {"description": "Connection established", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param service_free_cb: {"description": "Service free callback", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param data_cb_failed: {"description": "App DATA callback failed", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param wbuf_event: {"description": "Ready to send data", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param data_event: {"description": "Data received", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param service_alloc_cb_failed: {"description": "Service alloc callback failed", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param start_server_conn_fail_persist: {"description": "Fail Persistence", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param server_fin: {"description": "Server FIN", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param server_rst: {"description": "Server RST", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param start_server_conn_fail_snat: {"description": "Failed Source NAT", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param start_server_conn_no_route: {"description": "No route to server", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param tcp_event: {"description": "TCP stack event", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param no_mem: {"description": "No memory", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param event_failed: {"description": "Event failed", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param err_event: {"description": "Error occured", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param line_too_long: {"description": "Line too long", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param wbuf_cb_failed: {"description": "App WBUF callback failed", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param err_cb_failed: {"description": "App ERR callback failed", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param client_fin: {"description": "Client FIN", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param est_cb_failed: {"description": "App EST callback failed", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param start_server_conn_succ: {"description": "Success", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param conn_not_exist: {"description": "Conn not exist", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.start_server_conn = ""
        self.service_alloc_cb = ""
        self.start_server_conn_fail_tuple = ""
        self.client_rst = ""
        self.queue_depth_over_limit = ""
        self.start_server_conn_fail_mem = ""
        self.start_server_conn_fail_server = ""
        self.service_free_cb_failed = ""
        self.est_event = ""
        self.service_free_cb = ""
        self.data_cb_failed = ""
        self.wbuf_event = ""
        self.data_event = ""
        self.service_alloc_cb_failed = ""
        self.start_server_conn_fail_persist = ""
        self.server_fin = ""
        self.server_rst = ""
        self.start_server_conn_fail_snat = ""
        self.start_server_conn_no_route = ""
        self.tcp_event = ""
        self.no_mem = ""
        self.event_failed = ""
        self.err_event = ""
        self.line_too_long = ""
        self.wbuf_cb_failed = ""
        self.err_cb_failed = ""
        self.client_fin = ""
        self.est_cb_failed = ""
        self.start_server_conn_succ = ""
        self.conn_not_exist = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Proxy(A10BaseClass):
    
    """Class Description::
    Statistics for the object proxy.

    Class proxy supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/proxy/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "proxy"
        self.a10_url="/axapi/v3/slb/proxy/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Static(A10BaseClass):
    
    """Class Description::
    static ARP Commands.

    Class static supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ethernet: {"not": "trunk", "optional": true, "type": "number", "description": "Ethernet port (Port Value)", "format": "interface"}
    :param ip_addr: {"optional": false, "type": "string", "description": "IP address", "format": "ipv4-address"}
    :param mac_addr: {"optional": true, "type": "string", "description": "MAC address", "format": "mac-address"}
    :param vlan: {"description": "VLAN ID", "format": "number", "type": "number", "maximum": 4094, "minimum": 1, "optional": true}
    :param trunk: {"description": "Trunk group", "format": "number", "optional": true, "maximum": 16, "minimum": 1, "not": "ethernet", "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network/arp/static/{ip_addr}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ip_addr"]

        self.b_key = "static"
        self.a10_url="/axapi/v3/network/arp/static/{ip_addr}"
        self.DeviceProxy = ""
        self.ethernet = ""
        self.ip_addr = ""
        self.mac_addr = ""
        self.vlan = ""
        self.trunk = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Attribute(A10BaseClass):
    
    """Class Description::
    Authorization-policy attribute configuration.

    Class attribute supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param attribute_name: {"description": "Specify attribute name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "A10-AX-AUTH-URI", "type": "string"}
    :param integer_type: {"default": 0, "not": "string-type", "type": "number", "optional": true, "format": "flag"}
    :param custom_attr_type: {"default": 0, "optional": true, "type": "number", "description": "Specify attribute type", "format": "flag"}
    :param attr_type: {"default": 0, "optional": true, "type": "number", "description": "Specify attribute type", "format": "flag"}
    :param attr_str: {"optional": true, "enum": ["match", "sub-string"], "type": "string", "description": "'match': Operation type is match; 'sub-string': Operation type is sub-string; ", "format": "enum"}
    :param a10_dynamic_defined: {"default": 0, "optional": true, "type": "number", "description": "The value of this attribute will depend on AX configuration instead of user configuration", "format": "flag"}
    :param attr_str_val: {"description": "Set attribute value", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param string_type: {"default": 0, "not": "integer-type", "type": "number", "optional": true, "format": "flag"}
    :param attr_num: {"description": "Set attribute ID for authorization policy", "format": "number", "type": "number", "maximum": 32, "minimum": 1, "optional": false}
    :param A10_AX_AUTH_URI: {"description": "Custom-defined attribute", "format": "flag", "default": 0, "optional": true, "not": "attribute-name", "type": "number"}
    :param attr_int: {"optional": true, "enum": ["equal", "not-equal", "less-than", "more-than", "less-than-equal-to", "more-than-equal-to"], "type": "string", "description": "'equal': Operation type is equal; 'not-equal': Operation type is not equal; 'less-than': Operation type is less-than; 'more-than': Operation type is more-than; 'less-than-equal-to': Operation type is less-than-equal-to; 'more-than-equal-to': Operation type is more-thatn-equal-to; ", "format": "enum"}
    :param custom_attr_str: {"optional": true, "enum": ["match", "sub-string"], "type": "string", "description": "'match': Operation type is match; 'sub-string': Operation type is sub-string; ", "format": "enum"}
    :param attr_int_val: {"optional": true, "type": "number", "description": "Set attribute value", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authorization/policy/{name}/attribute/{attr_num}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "attr_num"]

        self.b_key = "attribute"
        self.a10_url="/axapi/v3/aam/authorization/policy/{name}/attribute/{attr_num}"
        self.DeviceProxy = ""
        self.attribute_name = ""
        self.integer_type = ""
        self.custom_attr_type = ""
        self.attr_type = ""
        self.attr_str = ""
        self.a10_dynamic_defined = ""
        self.attr_str_val = ""
        self.string_type = ""
        self.attr_num = ""
        self.A10_AX_AUTH_URI = ""
        self.attr_int = ""
        self.custom_attr_str = ""
        self.attr_int_val = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param peak_conn: {"description": "Peak connections", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param curr_conn: {"description": "Current connections", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param rev_pkt: {"description": "Reverse packets", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param fwd_pkt: {"description": "Forward packets", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param total_conn: {"description": "Total connections", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.peak_conn = ""
        self.curr_conn = ""
        self.rev_pkt = ""
        self.fwd_pkt = ""
        self.total_conn = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Server(A10BaseClass):
    
    """Class Description::
    Statistics for the object server.

    Class server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param port_list: {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["port-number", "protocol"], "properties": {"stats": {"type": "object", "properties": {"es_resp_invalid_http": {"description": "Total non-http response", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}, "curr_req": {"description": "Current requests", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}, "total_rev_pkts_inspected_good_status_code": {"description": "Total reverse packets with good status code inspected", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}, "es_resp_count": {"description": "Total proxy response", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}, "total_fwd_bytes": {"description": "Forward bytes", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}, "es_resp_other": {"description": "Response status other", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}, "fastest_rsp_time": {"description": "Fastest response time", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}, "total_fwd_pkts": {"description": "Forward packets", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}, "es_req_count": {"description": "Total proxy request", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}, "es_resp_500": {"description": "Response status 500", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}, "peak_conn": {"description": "Peak connections", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}, "total_req": {"description": "Total Requests", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}, "es_resp_400": {"description": "Response status 400", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}, "es_resp_300": {"description": "Response status 300", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}, "curr_conn": {"description": "Current connections", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}, "es_resp_200": {"description": "Response status 200", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}, "total_rev_bytes": {"description": "Reverse bytes", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}, "response_time": {"description": "Response time", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}, "total_conn": {"description": "Total connections", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}, "total_rev_pkts": {"description": "Reverse packets", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}, "total_req_succ": {"description": "Total requests succ", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}, "last_total_conn": {"description": "Last total connections", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}, "total_rev_pkts_inspected": {"description": "Total reverse packets inspected", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}, "slowest_rsp_time": {"description": "Slowest response time", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}}}, "protocol": {"enum": ["tcp", "udp"], "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum", "type": "string", "oid": "1002", "optional": false}, "port-number": {"description": "Port Number", "format": "number", "optional": false, "oid": "1001", "maximum": 65534, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/slb/server/{name}/port/{port-number}+{protocol}"}
    :param name: {"description": "Server Name", "format": "string-rlx", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/server/{name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "server"
        self.a10_url="/axapi/v3/slb/server/{name}/stats"
        self.DeviceProxy = ""
        self.port_list = []
        self.stats = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ClientDomainSwitching(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param service_group: {"description": "Select service group (Service group name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param match_string: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Domain name string", "format": "string-rlx"}
    :param switching_type: {"enum": ["contains", "ends-with", "starts-with"], "type": "string", "description": "'contains': Specify domain name string if domain contains another string; 'ends-with': Specify domain name string if domain ends with another string; 'starts-with': Specify domain string if domain starts with another string; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "client-domain-switching"
        self.DeviceProxy = ""
        self.service_group = ""
        self.match_string = ""
        self.switching_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CommandDisable(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param disable_type: {"enum": ["expn", "turn", "vrfy"], "type": "string", "description": "'expn': Disable SMTP EXPN commands; 'turn': Disable SMTP TURN commands; 'vrfy': Disable SMTP VRFY commands; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "command-disable"
        self.DeviceProxy = ""
        self.disable_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Smtp(A10BaseClass):
    
    """Class Description::
    SMTP.

    Class smtp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "SMTP Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param starttls: {"description": "'disabled': Disable STARTTLS; 'optional': STARTTLS is optional requirement; 'enforced': Must issue STARTTLS command before mail transaction; ", "format": "enum", "default": "disabled", "type": "string", "enum": ["disabled", "optional", "enforced"], "optional": true}
    :param server_domain: {"description": "Config the domain of the email servers (Server's domain, default is \"mail-server-domain\")", "format": "string-rlx", "default": "mail-server-domain", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param client_domain_switching: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"service-group": {"description": "Select service group (Service group name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "match-string": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Domain name string", "format": "string-rlx"}, "optional": true, "switching-type": {"enum": ["contains", "ends-with", "starts-with"], "type": "string", "description": "'contains': Specify domain name string if domain contains another string; 'ends-with': Specify domain name string if domain ends with another string; 'starts-with': Specify domain string if domain starts with another string; ", "format": "enum"}}}]}
    :param command_disable: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "disable-type": {"enum": ["expn", "turn", "vrfy"], "type": "string", "description": "'expn': Disable SMTP EXPN commands; 'turn': Disable SMTP TURN commands; 'vrfy': Disable SMTP VRFY commands; ", "format": "enum"}}}]}
    :param service_ready_msg: {"description": "Set SMTP service ready message (SMTP service ready message, default is \"ESMTP mail service ready\")", "format": "string-rlx", "default": "ESMTP mail service ready", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/smtp/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "smtp"
        self.a10_url="/axapi/v3/slb/template/smtp/{name}"
        self.DeviceProxy = ""
        self.name = ""
        self.starttls = ""
        self.server_domain = ""
        self.client_domain_switching = []
        self.command_disable = []
        self.service_ready_msg = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


